The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

# Changelog

## v1.0.0 (2024-08-19)

Initial release of `saltext-namecheap`. This release tracks the functionality in the core Salt code base as of version 3007.1.
